@@ -12,6 +12,9 @@ from kivy.uix.widget import Widget
 from kivy.uix.scatter import Scatter
 from kivy.uix.textinput import TextInput
 from kivy.uix.treeview import TreeView, TreeViewLabel
+from kivy.uix.switch import Switch
+from kivy.uix.label import Label
+from kivy.uix.popup import Popup
 
 
 class Showcase(FloatLayout):
@@ -68,6 +71,9 @@ class ShowcaseApp(App):
         n = create_tree('TreeView')
         attach_node('Standard treeview', n)
         attach_node('Treeview without root', n)
+        n = create_tree('Others')
+        attach_node('Popup', n)
+        attach_node('Switch', n)
         root.add_widget(tree)
         self.content = content = BoxLayout()
         root.add_widget(content)
@@ -124,11 +130,43 @@ class ShowcaseApp(App):
                                  multiline=False))
         return col
 
+    def show_switch(self):
+        col = AnchorLayout()
+        col.add_widget(Switch(active=True))
+        return col
+
+    def show_popup(self):
+        btnclose = Button(text='Close this popup', size_hint_y=None, height=50)
+        content = BoxLayout(orientation='vertical')
+        content.add_widget(Label(text='Hello world'))
+        content.add_widget(btnclose)
+        popup = Popup(content=content, title='Modal popup example',
+                      size_hint=(None, None), size=(300, 300),
+                      auto_dismiss=False)
+        btnclose.bind(on_release=popup.dismiss)
+        button = Button(text='Open popup', size_hint=(None, None),
+                        size=(150, 70))
+        button.bind(on_release=popup.open)
+        popup.open()
+        col = AnchorLayout()
+        col.add_widget(button)
+        return col
+
     def show_standard_treeview(self):
         return self.populate_treeview(TreeView())
 
     def show_treeview_without_root(self):
-        return self.populate_treeview(TreeView(hide_root=True))
+        # test with removing a node
+        col = BoxLayout(orientation='vertical')
+        tv = self.populate_treeview(TreeView(hide_root=True))
+        col.add_widget(tv)
+        btn = Button(text='Remove one node', size_hint_y=None, height=50)
+        def remove_node(*l):
+            if not tv.root.is_leaf:
+                tv.remove_node(tv.root.nodes[0])
+        btn.bind(on_release=remove_node)
+        col.add_widget(btn)
+        return col
 
     def populate_treeview(self, tv):
         n = tv.add_node(TreeViewLabel(text='Item 1'))
