@@ -4,7 +4,7 @@ kivy.require('1.0.6')
 from kivy.app import App
 from kivy.uix.floatlayout import FloatLayout
 from kivy.uix.label import Label
-from kivy.graphics import Color, Rectangle, Point
+from kivy.graphics import Color, Rectangle, Point, GraphicException
 from random import random
 from math import sqrt
 
@@ -52,9 +52,12 @@ class Touchtracer(FloatLayout):
         oldx, oldy = points[-2], points[-1]
         points = calculate_points(oldx, oldy, touch.x, touch.y)
         if points:
-            lp = ud['lines'][2].add_point
-            for idx in xrange(0, len(points), 2):
-                lp(points[idx], points[idx+1])
+            try:
+                lp = ud['lines'][2].add_point
+                for idx in xrange(0, len(points), 2):
+                    lp(points[idx], points[idx+1])
+            except GraphicException:
+                pass
 
         ud['label'].pos = touch.pos
         self.update_touch_label(ud['label'], touch)
