@@ -75,6 +75,7 @@ next frame.
 
     :func:`Clock.create_trigger` use internally schedule_once. You can use the
     same parameters.
+
 '''
 
 __all__ = ('Clock', 'ClockBase', 'ClockEvent')
@@ -339,7 +340,7 @@ class ClockBase(object):
         # call that function to release all the direct reference to any callback
         # and replace it with a weakref
         events = self._events
-        for cid in events:
+        for cid in events.keys()[:]:
             [x.release() for x in events[cid] if x.callback is not None]
 
     def _remove_empty(self):
@@ -364,10 +365,11 @@ class ClockBase(object):
         events = self._events
         while found:
             count -= 1
-            if count < 0:
+            if count == -1:
                 Logger.critical('Clock: Warning, too much iteration done before'
-                                ' the next frame. Check your code, or increase '
-                                'the Clock.max_iteration attribute')
+                                ' the next frame. Check your code, or increase'
+                                ' the Clock.max_iteration attribute')
+                break
 
             # search event that have timeout = -1
             found = False
@@ -381,11 +383,6 @@ class ClockBase(object):
                         if event in events[cid]:
                             events[cid].remove(event)
 
-        if count != self.max_iteration - 1:
-            i = self.max_iteration - count + 1
-            if __debug__:
-                Logger.trace('Clock: we done %d iteration before the frame' % i)
-
 
 if 'KIVY_DOC_INCLUDE' in environ:
     #: Instance of the ClockBase, available for everybody
