@@ -14,6 +14,8 @@ __all__ = ('start', 'stop')
 def _on_keyboard_handler(instance, key, scancode, unicode, modifier):
     if key == 293: # F12
         instance.screenshot()
+    elif key == 292: # F11
+        instance.rotation += 90
 
 
 def start(win, ctx):
