@@ -48,7 +48,7 @@ from kivy.cache import Cache
 from kivy.core.image import Image as CoreImage
 from kivy.resources import resource_find
 from kivy.properties import StringProperty, ObjectProperty, ListProperty, \
-        AliasProperty
+        AliasProperty, BooleanProperty
 from kivy.loader import Loader
 
 
@@ -88,6 +88,16 @@ class Image(Widget):
             return self.texture.width / float(self.texture.height)
         return 1.
 
+    mipmap = BooleanProperty(False)
+    '''Indicate if you want OpenGL mipmapping to be apply on the texture or not.
+    Read :ref:`mipmap` for more informations.
+
+    .. versionadded:: 1.0.7
+
+    :data:`mipmap` is a :class:`~kivy.properties.BooleanProperty`, default to
+    False.
+    '''
+
     image_ratio = AliasProperty(get_image_ratio, None, bind=('texture', ))
     '''Ratio of the image (width / float(height)
 
@@ -106,6 +116,17 @@ class Image(Widget):
     1, 1].
     '''
 
+    allow_stretch = BooleanProperty(False)
+    '''If True, the normalized image size will be maximized to fit in the image
+    box. Otherwise, if the box is too higher, the image will be not strech more
+    that 1:1 pixels
+
+    .. versionadded:: 1.0.7
+
+    :data:`allow_stretch` is a :class:`~kivy.properties.BooleanProperty`,
+    default to False
+    '''
+
     def get_norm_image_size(self):
         if not self.texture:
             return self.size
@@ -114,20 +135,26 @@ class Image(Widget):
         tw, th = self.texture.size
 
         # ensure that the width is always maximized to the containter width
-        iw = w if tw < w else w
+        if self.allow_stretch:
+            iw = w
+        else:
+            iw = min(w, tw)
         # calculate the appropriate height
         ih = iw / ratio
         # if the height is too higher, take the height of the container
         # and calculate appropriate width. no need to test further. :)
         if ih > h:
-            ih = h
+            if self.allow_stretch:
+                ih = h
+            else:
+                ih = min(h, th)
             iw = ih * ratio
 
         return iw, ih
 
 
     norm_image_size = AliasProperty(get_norm_image_size, None, bind=(
-        'texture', 'size', 'image_ratio'))
+        'texture', 'size', 'image_ratio', 'allow_stretch'))
     '''Normalized image size withing the widget box.
 
     This size will be always fitted to the widget size, and preserve the image
@@ -137,16 +164,27 @@ class Image(Widget):
     read-only.
     '''
 
-    def on_source(self, instance, value):
-        if not value:
+    def __init__(self, **kwargs):
+        super(Image, self).__init__(**kwargs)
+        self.bind(source=self.texture_update,
+                  mipmap=self.texture_update)
+        if self.source is not None:
+            self.texture_update()
+
+    def texture_update(self, *largs):
+        if not self.source:
             self.texture = None
         else:
-            filename = resource_find(value)
-            texture = Cache.get('kv.texture', filename)
+            filename = resource_find(self.source)
+            if filename is None:
+                return
+            mipmap = self.mipmap
+            uid = '%s|%s' % (filename, mipmap)
+            texture = Cache.get('kv.texture', uid)
             if not texture:
-                image = CoreImage(filename)
+                image = CoreImage(filename, mipmap=mipmap)
                 texture = image.texture
-                Cache.append('kv.texture', filename, texture)
+                Cache.append('kv.texture', uid, texture)
             self.texture = texture
 
     def on_texture(self, instance, value):
@@ -161,14 +199,17 @@ class AsyncImage(Image):
     def __init__(self, **kwargs):
         self._coreimage = None
         super(AsyncImage, self).__init__(**kwargs)
+        self.unbind(source=self.texture_update,
+                    mipmap=self.texture_update)
 
     def on_source(self, instance, value):
         if not value:
             self.texture = None
             self._coreimage = None
         else:
-            filename = resource_find(value)
-            self._coreimage = image = Loader.image(filename)
+            if not self.is_uri(value):
+                value = resource_find(value)
+            self._coreimage = image = Loader.image(value)
             image.bind(on_load=self.on_source_load)
             self.texture = image.texture
 
@@ -178,3 +219,7 @@ class AsyncImage(Image):
             return
         self.texture = image.texture
 
+    def is_uri(self, filename):
+        proto = filename.split('://', 1)[0]
+        return proto in ('http', 'https', 'ftp')
+
