@@ -100,6 +100,7 @@ class Widget(EventDispatcher):
         # of doing that without require any python code. :)
         Widget.__widget_uid += 1
         self.__dict__['__uid'] = Widget.__widget_uid
+        self.__dict__['__storage'] = {}
 
         cp = Widget.__cache_properties
         if __cls__ not in cp:
@@ -128,13 +129,6 @@ class Widget(EventDispatcher):
         # Then, return the class instance
         return self
 
-    def __del__(self):
-        # The thing here, since the storage of the property is inside the
-        # Property class, we must remove ourself from the storage of each
-        # Property. The usage is faster, the creation / deletion is longer.
-        for attr in self.__properties.itervalues():
-            attr.unlink(self)
-
     def __init__(self, **kwargs):
         super(Widget, self).__init__()
 
@@ -161,7 +155,7 @@ class Widget(EventDispatcher):
 
         # Apply the existing arguments to our widget
         for key, value in kwargs.iteritems():
-            if hasattr(self, key):
+            if key in properties:
                 setattr(self, key, value)
 
         # Apply all the styles
@@ -566,6 +560,16 @@ class Widget(EventDispatcher):
     '''Class of the widget, used for styling.
     '''
 
+    def get_uid(self):
+        return self.__dict__['__uid']
+    uid = AliasProperty(get_uid, None)
+    '''Unique identifier of the widget in the whole Kivy instance.
+
+    .. versionadded:: 1.0.7
+
+    :data:`uid` is a :class:`~kivy.properties.AliasProperty`, read-only.
+    '''
+
     id = StringProperty(None, allownone=True)
     '''Unique identifier of the widget in the tree.
 
